import numpy as np
import threading
from edgeiq._constants import EDGEIQ_LOGS as EDGEIQ_LOGS
from enum import Enum
from typing import Any, Optional, Union

class CameraFailedToStart(RuntimeError):
    def __init__(self, cmd: str, backend: str, append: int = ...) -> None: ...

class CameraConnectionLost(RuntimeError):
    def __init__(self) -> None: ...

class _BaseVideoStream:
    def __init__(self, cmd: Union[str, int], backend: int) -> None: ...
    def start(self): ...
    @property
    def fps(self) -> float: ...
    def read(self) -> np.ndarray: ...
    def read_non_blocking(self) -> Optional[np.ndarray]: ...
    def stop(self) -> None: ...
    def __enter__(self): ...
    def __exit__(self, type, value, traceback) -> None: ...

class WebcamVideoStream(_BaseVideoStream):
    def __init__(self, cam: int = ...) -> None: ...

class GStreamerVideoStream(_BaseVideoStream):
    def __init__(self, cam: int = ..., display_width: int = ..., display_height: int = ..., framerate: int = ...) -> None: ...

class GStreamerCustomVideoStream(_BaseVideoStream):
    def __init__(self, cmd: str) -> None: ...

class FrameRotation(Enum):
    ROTATE_NONE: int
    ROTATE_90: int
    ROTATE_180: int

class JetsonCameraMode(Enum):
    IMX219_3264x2468_21_0: int
    IMX219_3264x1848_28_1: int
    IMX219_1920x1080_30_2: int
    IMX219_1640x1232_30_3: int
    IMX477_4032x3040_30_0: int
    IMX477_1920x1080_60_1: int
    IMX477_2560x1440_40_3: int

class JetsonVideoStream(_BaseVideoStream):
    def __init__(self, cam: int = ..., rotation: FrameRotation = ..., camera_mode: JetsonCameraMode = ..., display_width: int = ..., display_height: int = ...) -> None: ...

class IPVideoStream(_BaseVideoStream):
    def __init__(self, url: str) -> None: ...

class NoMoreFrames(RuntimeError):
    def __init__(self) -> None: ...

class _FileVideoStreamThread(threading.Thread):
    def __init__(self, stream: Any, queue_size: int, *args, **kwargs) -> None: ...
    @property
    def more(self) -> bool: ...
    def read(self) -> np.ndarray: ...
    def stop(self) -> None: ...
    def run(self) -> None: ...

class _RealtimeFileVideoStreamThread(threading.Thread):
    def __init__(self, stream: Any, fps: int, *args, **kwargs) -> None: ...
    @property
    def more(self) -> bool: ...
    def read(self) -> np.ndarray: ...
    def stop(self) -> None: ...
    def run(self) -> None: ...

class FileVideoStream:
    def __init__(self, path: str, queue_size: int = ..., play_realtime: bool = ..., fps: Optional[int] = ...) -> None: ...
    @property
    def fps(self) -> Optional[int]: ...
    def start(self): ...
    def read(self) -> np.ndarray: ...
    def more(self) -> bool: ...
    def stop(self) -> None: ...
    def __enter__(self): ...
    def __exit__(self, type, value, traceback) -> None: ...
    def __del__(self) -> None: ...
